@@ -1,7 +1,6 @@
 package inc::MyBuilder;
 
 use File::Spec;
-use IO::Any;
 use base 'Module::Build';
 
 sub ACTION_build {
@@ -12,15 +11,19 @@ sub ACTION_build {
 	my %notes = $self->notes;
 	my $path_types = $notes{'path_types'};
 	
-	my $config_fh      = IO::Any->read(['default', 'SPc.pm']);
-	my $blib_config_fh = IO::Any->write([$self->blib, 'lib', 'SPc.pm']);
+	# write the new version of SPc.pm
+	open(my $config_fh, '<', File::Spec->catfile('default', 'SPc.pm')) or die $!;
+	open(my $blib_config_fh, '>', File::Spec->catfile($self->blib, 'lib', 'SPc.pm')) or die $!;
 	while (my $line = <$config_fh>) {
+		next if ($line =~ m/# remove after install$/);
 		if ($line =~ m/^sub \s+ ($path_types) \s* {/xms) {
 			$line = 'sub '.$1." {'".$notes{$1}."'};"."\n"
 				if exists $notes{$1};
 		}
 		print $blib_config_fh $line;
 	}
+	close($blib_config_fh);
+	close($config_fh);
 	
 	return;
 }
